@@ -23,7 +23,7 @@
 
 #include "incidenceeditor_export.h"
 
-#include <KCalCore/IncidenceBase>
+#include <KCalendarCore/IncidenceBase>
 #include <Collection>
 
 namespace Akonadi {
@@ -49,7 +49,7 @@ namespace IncidenceDialogFactory {
  * NOTE: There is no editor for Incidence::TypeFreeBusy
  */
 INCIDENCEEDITOR_EXPORT IncidenceDialog *create(
-    bool needsSaving, KCalCore::IncidenceBase::IncidenceType type, Akonadi::IncidenceChanger *changer, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
+    bool needsSaving, KCalendarCore::IncidenceBase::IncidenceType type, Akonadi::IncidenceChanger *changer, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
 
 INCIDENCEEDITOR_EXPORT IncidenceDialog *createTodoEditor(
     const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes, const QStringList &attachmentLabels,
